"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FoundationComponent = void 0;
const tslib_1 = require("tslib");
const path = require("path");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const pkginfo_1 = require("@libit/pkginfo");
const translate_1 = require("@libit/translate");
const swstats = tslib_1.__importStar(require("swagger-stats"));
const keys_1 = require("./keys");
const logger_1 = require("./components/logger");
let FoundationComponent = class FoundationComponent {
    constructor(app, options) {
        var _a, _b, _c, _d, _e, _f;
        this.app = app;
        this.options = options;
        this.bindings = [];
        const [info, dir] = pkginfo_1.appinfo.sync(true);
        // Resolve options
        this.options = options !== null && options !== void 0 ? options : {};
        if (!this.options.projectRoot) {
            this.options.projectRoot = dir;
        }
        if (!this.options.projectName) {
            this.options.projectName = info.name;
        }
        if (!this.options.projectVersion) {
            this.options.projectVersion = info.version;
        }
        const { projectName } = this.options;
        // Mount logger component
        app.bind(logger_1.LoggerBindings.CONFIG).to({
            name: projectName,
            ...options === null || options === void 0 ? void 0 : options.logger,
        });
        app.component(logger_1.LoggerComponent);
        // Bind translator
        const resourceDir = (_b = (_a = this.options.translator) === null || _a === void 0 ? void 0 : _a.resourceDir) !== null && _b !== void 0 ? _b : path.join(__dirname, '..', 'intl');
        const translator = translate_1.createTranslator('foundation', resourceDir);
        this.bindings.push(core_1.Binding.bind(keys_1.FoundationBindings.TRANSLATOR).to(translator));
        // Enable OBF
        if (((_c = this.options) === null || _c === void 0 ? void 0 : _c.obf) && ((_d = this.options) === null || _d === void 0 ? void 0 : _d.obf.enabled) !== false && ((_e = this.options) === null || _e === void 0 ? void 0 : _e.obf.openapiSpec)) {
            const { obf } = this.options;
            const swStatsMiddleware = swstats.getMiddleware({
                uriPath: (_f = obf.uri) !== null && _f !== void 0 ? _f : `/obf`,
                swaggerSpec: obf.openapiSpec,
                authentication: Boolean(obf.authentication),
                onAuthenticate: obf.authenticate
                    ? obf.authenticate
                    : (req, username, password) => {
                        return username === obf.username && password === obf.password;
                    },
            });
            app.expressMiddleware(keys_1.FoundationBindings.SWSTATS_MIDDLEWARE, swStatsMiddleware);
        }
    }
};
FoundationComponent = tslib_1.__decorate([
    tslib_1.__param(0, core_1.inject(core_1.CoreBindings.APPLICATION_INSTANCE)),
    tslib_1.__param(1, core_1.inject(keys_1.FoundationBindings.CONFIG, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [rest_1.RestApplication, Object])
], FoundationComponent);
exports.FoundationComponent = FoundationComponent;
//# sourceMappingURL=component.js.map