import isEmpty from 'tily/is/empty';
import {securityId} from '@loopback/security';
import {AuthorizationContext, AuthorizationDecision, AuthorizationMetadata} from '@loopback/authorization';
import pupa = require('pupa');

/**
 * Allow for the request user id equals the login user id.
 *
 * @param id id template string in arguments. e.g. {0} for first argument, {1} for second argument.
 */
export function authorizeSelf(id = '{0}') {
  return async (
    authorizationCtx: AuthorizationContext,
    metadata: AuthorizationMetadata,
  ): Promise<AuthorizationDecision> => {
    const principal = authorizationCtx.principals[0];
    if (!principal) {
      return AuthorizationDecision.ABSTAIN;
    }

    if (isEmpty(authorizationCtx.invocationContext.args)) {
      return AuthorizationDecision.ALLOW;
    }

    const userId = principal[securityId] ?? principal.id;
    const reqUserId = pupa(id, authorizationCtx.invocationContext.args);
    if (userId === reqUserId) {
      return AuthorizationDecision.ALLOW;
    }
    return AuthorizationDecision.ABSTAIN;
  };
}
